<?php
/**
 * Home Page Options.
 *
 * @package Fotoografia
 */

$default = fotoografia_get_default_theme_options();

// Latest Latest Posts Section
$wp_customize->add_section( 'archive_blog_page',
	array(
		'title'      => __( 'Archive/Blog', 'fotoografia' ),
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
		)
);

// Header Font Size
$wp_customize->add_setting('theme_options[archive_header_image_padding]', 
	array(
	'sanitize_callback' => 'absint',
	'default'			=> 150,
	)
);

$wp_customize->add_control(new Fotoografia_Range_Value_Control($wp_customize,'theme_options[archive_header_image_padding]',
	array(
		'type'     => 'range-value',
		'section'  => 'archive_blog_page',
		'label'    => esc_html__( 'Header Image Padding(px)', 'fotoografia' ),
		'description' => __(' Default:150px. Max:400px Min:60px .', 'fotoografia'),
		'input_attrs' => array(
			'min'    => 60,
			'max'    => 400,
			'step'   => 1,
	)
)));

// Add arrow enable setting and control.
$wp_customize->add_setting( 'theme_options[archive_layout_option]', array(
	'default'           => $default['archive_layout_option'],
	'sanitize_callback' => 'fotoografia_sanitize_select',
) );

$wp_customize->add_control( 'theme_options[archive_layout_option]', array(
	'label'             => esc_html__( 'Choose Archive/Blog Layout', 'fotoografia' ),
	'section'           => 'archive_blog_page',
	'type'              => 'radio',
	'choices'				=> array( 
		'grid-layout'     => esc_html__( 'Grid Layout', 'fotoografia' ), 
		'list-layout'     => esc_html__( 'List Layout', 'fotoografia' ),
		)
) );
// Add arrow enable setting and control.
$wp_customize->add_setting( 'theme_options[archive_text_align_option]', array(
	'default'           => $default['archive_text_align_option'],
	'sanitize_callback' => 'fotoografia_sanitize_select',
) );

$wp_customize->add_control( 'theme_options[archive_text_align_option]', array(
	'label'             => esc_html__( 'Choose Archive/Blog Text Align Option', 'fotoografia' ),
	'section'           => 'archive_blog_page',
	'type'              => 'radio',
	'choices'				=> array( 
		'left'     => esc_html__( 'Text Align: Left', 'fotoografia' ),  
		'right'     => esc_html__( 'Text Align: Right', 'fotoografia' ),  
		'center'     => esc_html__( 'Text Align: Center', 'fotoografia' ),  
		'justify'     => esc_html__( 'Text Align: Justify', 'fotoografia' ),
		)
) );

// Setting excerpt_length.
$wp_customize->add_setting( 'theme_options[excerpt_length]', array(
	'default'           => $default['excerpt_length'],
	'sanitize_callback' => 'fotoografia_sanitize_positive_integer',
) );
$wp_customize->add_control( 'theme_options[excerpt_length]', array(
	'label'       => esc_html__( 'Excerpt Length', 'fotoografia' ),
	'description' => esc_html__( 'in words', 'fotoografia' ),
	'section'     => 'archive_blog_page',
	'type'        => 'number',
	'input_attrs' => array( 'min' => 1, 'max' => 200, 'style' => 'width: 55px;' ),
) );


// Add Single Header Image enable setting and control.
$wp_customize->add_setting( 'theme_options[archive_header_image_enable]', array(
	'default'           => $default['archive_header_image_enable'],
	'sanitize_callback' => 'fotoografia_sanitize_checkbox',
) );

$wp_customize->add_control( 'theme_options[archive_header_image_enable]', array(
	'label'             => esc_html__( 'Enable Header Image', 'fotoografia' ),
	'section'           => 'archive_blog_page',
	'type'              => 'checkbox',

) );

// Add category enable setting and control.
$wp_customize->add_setting( 'theme_options[archive_category_enable]', array(
	'default'           => $default['archive_category_enable'],
	'sanitize_callback' => 'fotoografia_sanitize_checkbox',
) );

$wp_customize->add_control( 'theme_options[archive_category_enable]', array(
	'label'             => esc_html__( 'Enable Category', 'fotoografia' ),
	'section'           => 'archive_blog_page',
	'type'              => 'checkbox',

) );

// Add posted on enable setting and control.
$wp_customize->add_setting( 'theme_options[archive_posted_on_enable]', array(
	'default'           => $default['archive_posted_on_enable'],
	'sanitize_callback' => 'fotoografia_sanitize_checkbox',
) );

$wp_customize->add_control( 'theme_options[archive_posted_on_enable]', array(
	'label'             => esc_html__( 'Enable Date', 'fotoografia' ),
	'section'           => 'archive_blog_page',
	'type'              => 'checkbox',

) );

// Add posted on enable setting and control.
$wp_customize->add_setting( 'theme_options[archive_author_enable]', array(
	'default'           => $default['archive_author_enable'],
	'sanitize_callback' => 'fotoografia_sanitize_checkbox',
) );

$wp_customize->add_control( 'theme_options[archive_author_enable]', array(
	'label'             => esc_html__( 'Enable Author', 'fotoografia' ),
	'section'           => 'archive_blog_page',
	'type'              => 'checkbox',

) );

// Add category enable setting and control.
$wp_customize->add_setting( 'theme_options[archive_image_enable]', array(
	'default'           => $default['archive_image_enable'],
	'sanitize_callback' => 'fotoografia_sanitize_checkbox',
) );

$wp_customize->add_control( 'theme_options[archive_image_enable]', array(
	'label'             => esc_html__( 'Enable Featured Image', 'fotoografia' ),
	'section'           => 'archive_blog_page',
	'type'              => 'checkbox',

) );

// Header Font Size
$wp_customize->add_setting('theme_options[archive_font_size]', 
	array(
	'sanitize_callback' => 'absint',
	'default'			=> 30,
	)
);

$wp_customize->add_control(new Fotoografia_Range_Value_Control($wp_customize,'theme_options[archive_font_size]',
	array(
		'type'     => 'range-value',
		'section'  => 'archive_blog_page',
	
		'label'    => esc_html__( 'Header Font Size(px)', 'fotoografia' ),
		'description' => __(' Default:30px. Max:45px Min:16px .', 'fotoografia'),
		'input_attrs' => array(
			'min'    => 16,
			'max'    => 45,
			'step'   => 1,
	)
)));

$wp_customize->add_setting('theme_options[archive_readmore_text]', 
	array(

	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[archive_readmore_text]', 
	array(
	'label'       => __('Button Label', 'fotoografia'),
	'section'     => 'archive_blog_page',   
	'settings'    => 'theme_options[archive_readmore_text]',	
	'type'        => 'text'
	)
);
// Number of Services
$wp_customize->add_setting('theme_options[number_of_archive_posts_column]', 
	array(
	'default' 			=> $default['number_of_archive_posts_column'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'fotoografia_sanitize_number_range'
	)
);

$wp_customize->add_control('theme_options[number_of_archive_posts_column]', 
	array(
	'label'       => __('Column Per Row', 'fotoografia'),
	'description' => __('Save & Refresh the customizer to see its effect. Maximum is 5', 'fotoografia'),
	'section'     => 'archive_blog_page',   
	'settings'    => 'theme_options[number_of_archive_posts_column]',		
	'type'        => 'number',
	'input_attrs' => array(
			'min'	=> 1,
			'max'	=> 5,
			'step'	=> 1,
		),
	)
);

$wp_customize->add_setting('theme_options[pagination_type]', 
	array(
	'default' 			=> $default['pagination_type'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'fotoografia_sanitize_select'
	)
);

$wp_customize->add_control('theme_options[pagination_type]', 
	array(
	'label'       => __('Pagination Type', 'fotoografia'),
	'section'     => 'archive_blog_page',   
	'settings'    => 'theme_options[pagination_type]',		
	'type'        => 'select',
	'choices'	  => array(
		'default' 		=> esc_html__( 'Default', 'fotoografia' ),
		'numeric' 		=> esc_html__( 'Numeric', 'fotoografia' ),
		),
	)
);