<?php
/**
 * Testimonial options.
 *
 * @package Fotoografia
 */

$default = fotoografia_get_default_theme_options();

// Testimonial Section
$wp_customize->add_section( 'section_home_testimonial',
	array(
		'title'      => __( 'Testimonial Section', 'fotoografia' ),
		'priority'   => 34,
		'capability' => 'edit_theme_options',
		'panel'      => 'home_page_panel',
		)
);

$wp_customize->add_setting( 'theme_options[disable_testimonial_section]',
	array(
		'default'           => $default['disable_testimonial_section'],
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'fotoografia_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Fotoografia_Switch_Control( $wp_customize, 'theme_options[disable_testimonial_section]',
    array(
		'label' 			=> __('Enable/Disable Testimonial Section', 'fotoografia'),
		'section'    		=> 'section_home_testimonial',
		'settings'  		=> 'theme_options[disable_testimonial_section]',
		'on_off_label' 		=> fotoografia_switch_options(),
    )
) );

//Testimonial Section title
$wp_customize->add_setting('theme_options[testimonial_title]', 
	array(
	'default'           => $default['testimonial_title'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[testimonial_title]', 
	array(
	'label'       => __('Section Title', 'fotoografia'),
	'section'     => 'section_home_testimonial',   
	'settings'    => 'theme_options[testimonial_title]',
	'active_callback' => 'fotoografia_testimonial_active',		
	'type'        => 'text'
	)
);

$wp_customize->add_setting('theme_options[testimonial_content_type]', 
	array(
	'default' 			=> $default['testimonial_content_type'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'fotoografia_sanitize_select'
	)
);

$wp_customize->add_control('theme_options[testimonial_content_type]', 
	array(
	'label'       => __('Content Type', 'fotoografia'),
	'section'     => 'section_home_testimonial',   
	'settings'    => 'theme_options[testimonial_content_type]',		
	'type'        => 'select',
	'active_callback' => 'fotoografia_testimonial_active',
	'choices'	  => array(
			'testimonial_post'	  => __('Post','fotoografia'),
			'testimonial_category'  => __('Category', 'fotoografia'),
		),
	)
);

// Setting  Testimonial Category.
$wp_customize->add_setting( 'theme_options[testimonial_category]',
	array(

	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	new Fotoografia_Dropdown_Taxonomies_Control( $wp_customize, 'theme_options[testimonial_category]',
		array(
		'label'    => __( 'Select Category', 'fotoografia' ),
		'section'  => 'section_home_testimonial',
		'settings' => 'theme_options[testimonial_category]',	
		'active_callback' => 'fotoografia_testimonial_category',		
		)
	)
);

for( $i=1; $i<=4; $i++ ){

	// Additional Information First Post
	$wp_customize->add_setting('theme_options[testimonial_post_'.$i.']', 
		array(
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',	
		'sanitize_callback' => 'fotoografia_dropdown_posts'
		)
	);
	$wp_customize->add_control( new Fotoografia_Dropdown_Chooser( $wp_customize,'theme_options[testimonial_post_'.$i.']', 
		array(
		'label'       => sprintf( __('Select Post #%1$s', 'fotoografia'), $i),
		'section'     => 'section_home_testimonial',  
		'settings'    => 'theme_options[testimonial_post_'.$i.']',	
		'choices'			=> fotoografia_post_choices(),	
		'type'        => 'dropdown-posts',
		'active_callback' => 'fotoografia_testimonial_post',
		)
	));
}


